@@ -489,7 +489,7 @@ def start(format: bool = False):
             docstring=docstring,
             slots=slots,
             id=c.id,
-            qualname=f"pyrogram.raw.{c.section}.{c.qualname}",
+            qualname=f"{c.section}.{c.qualname}",
             arguments=arguments,
             fields=fields,
             read_types=read_types,
